@@ -1,6 +1,7 @@
 package JMAP::Validation::Checks::String;
 
 use DateTime;
+use JMAP::Validation;
 use JMAP::Validation::Tests::String;
 use Test2::Bundle::Extended;
 
@@ -16,10 +17,18 @@ our $is_string = validator(sub {
 
 # restrictions {{{
 
-our $is_string_or_null = in_set(
-  $is_string,
-  not_in_set(D()),
-);
+our $is_string_or_null = validator(sub {
+  my (%params) = @_;
+
+ if (defined $params{got}) {
+   return unless JMAP::Validation::validate(
+     $params{got},
+     $is_string,
+   );
+ }
+
+ return 1;
+});
 
 our $has_at_least_one_character = check_set(
   $is_string,
